@@ -26,6 +26,8 @@ from .workspacebuilder import WorkspaceBuilder, freeze
 
 logger = logging.getLogger(__name__)
 
+VALID_CONFIG_DIR_FILE_EXTENSIONS = ['.yaml', '.yml', '.json']
+
 
 def get_cwd():
     return os.getcwd()
@@ -162,14 +164,15 @@ def set_layout_hook(session, hook_name):
     """
     cmd = ['set-hook', '-t', session.id, hook_name]
     hook_cmd = []
+    attached_window = session.attached_window
     for window in session.windows:
         # unfortunately, select-layout won't work unless
         # we've literally selected the window at least once
         # with the client
         hook_cmd.append('selectw -t {}'.format(window.id))
         # edit: removed -t, or else it won't respect main-pane-w/h
-        hook_cmd.append('selectl'.format(window.id))
-        hook_cmd.append('selectw -p'.format(window.id))
+        hook_cmd.append('selectl')
+        hook_cmd.append('selectw -p')
 
     # unset the hook immediately after executing
     hook_cmd.append(
@@ -177,6 +180,7 @@ def set_layout_hook(session, hook_name):
             target_session=session.id, hook_name=hook_name
         )
     )
+    hook_cmd.append('selectw -t {}'.format(attached_window.id))
 
     # join the hook's commands with semicolons
     hook_cmd = '{}'.format('; '.join(hook_cmd))
@@ -324,7 +328,7 @@ def scan_config(config, config_dir=None):
                 x
                 for x in [
                     '%s%s' % (join(config_dir, config), ext)
-                    for ext in ['.yaml', '.yml', '.json']
+                    for ext in VALID_CONFIG_DIR_FILE_EXTENSIONS
                 ]
                 if exists(x)
             ]
@@ -696,7 +700,7 @@ def command_freeze(session_name, socket_name, socket_path):
     print(
         '---------------------------------------------------------------'
         '\n'
-        'Freeze does it best to snapshot live tmux sessions.\n'
+        'Freeze does its best to snapshot live tmux sessions.\n'
     )
     if click.confirm(
         'The new config *WILL* require adjusting afterwards. Save config?'
@@ -922,3 +926,16 @@ def command_convert(config):
                 buf.write(newconfig)
                 buf.close()
                 print('New config saved to <%s>.' % newfile)
+
+
+@cli.command(
+    name='ls', short_help='List configured sessions in {}.'.format(get_config_dir())
+)
+def command_ls():
+    tmuxp_dir = get_config_dir()
+    if os.path.exists(tmuxp_dir) and os.path.isdir(tmuxp_dir):
+        for f in sorted(os.listdir(tmuxp_dir)):
+            stem, ext = os.path.splitext(f)
+            if os.path.isdir(f) or ext not in VALID_CONFIG_DIR_FILE_EXTENSIONS:
+                continue
+            print(stem)
